'use strict';

Object.defineProperty(exports, "__esModule", {
   value: true
});

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var customValidity = function customValidity(constraint) {
   var required = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
   return function (props, propName, componentName) {
      return !required && typeof props[propName] === 'undefined' || typeof props[propName] !== 'undefined' && constraint(props, propName, componentName) ? null : new Error('Invalid prop `' + propName + '` supplied to `' + componentName + '`. Validation failed.');
   };
};

var FormFieldPropTypes = {
   checked: _propTypes2.default.bool.isRequired,
   componentLibrary: _propTypes2.default.object.isRequired,
   name: _propTypes2.default.string.isRequired,
   type: _propTypes2.default.string.isRequired,
   value: _propTypes2.default.string.isRequired,
   autocomplete: _propTypes2.default.string,
   customValidity: _propTypes2.default.string,
   disabled: _propTypes2.default.bool,
   label: _propTypes2.default.string,
   // https://www.w3.org/TR/html5/forms.html#attr-input-max
   max: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
   // https://www.w3.org/TR/html5/forms.html#attr-fe-maxlength
   maxLength: customValidity(function (props, propName) {
      return Number.isInteger(props[propName]) && props[propName] >= 0;
   }),
   // https://www.w3.org/TR/html5/forms.html#attr-input-min
   min: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
   // https://www.w3.org/TR/html5/forms.html#attr-fe-minlength
   minLength: customValidity(function (props, propName) {
      return Number.isInteger(props[propName]) && props[propName] >= 0;
   }),
   onBlur: _propTypes2.default.func,
   onChange: _propTypes2.default.func,
   onFocus: _propTypes2.default.func,
   onInvalid: _propTypes2.default.func,
   onMouseEnter: _propTypes2.default.func,
   onMouseLeave: _propTypes2.default.func,
   // https://www.w3.org/TR/html5/forms.html#attr-input-pattern
   pattern: _propTypes2.default.string,
   placeholder: _propTypes2.default.string,
   radios: _propTypes2.default.array,
   // https://www.w3.org/TR/html5/forms.html#attr-input-required
   required: customValidity(function (props, propName) {
      return typeof props[propName] === 'boolean' && props.type !== 'radiogroup';
   }),
   rows: customValidity(function (props, propName) {
      return props.type === 'textarea' && Number.isInteger(props[propName]) && props[propName] > 0;
   }),
   // https://www.w3.org/TR/html5/forms.html#attr-input-step
   step: customValidity(function (props, propName) {
      return !Number.isNaN(props[propName]) || props[propName] === 'any';
   })
};

exports.default = FormFieldPropTypes;